import std/json, std/options, std/strutils, std/unittest

import private/encoding
import ../testdata

suite "private/encoding":

  test "b64UrlEncode(int array)":
    check:
      rfc7519Sec3_1ExampleHeaderB64 == b64UrlEncode(rfc7519Sec3_1ExampleHeaderBytes)
      rfc7519Sec3_1ExampleClaimsB64 == b64UrlEncode(rfc7519Sec3_1ExampleClaimsBytes)

  test "b64UrlEncode(string)":
    let jwtParts = sampleJwt.split('.')

    check:
      b64UrlEncode(sampleJwtHeaderDecoded) == jwtParts[0]
      b64UrlEncode(sampleJwtClaimsDecoded) == jwtParts[1]

      # Nim mangles \r\n somehow, causing the below to fail. However, the
      # failure is at the string literal -> string var layer, not the encoding
      # layer)
      # rfc7519Sec3_1ExampleHeaderB64 == b64UrlEncode(rfc7519Sec3_1ExampleHeaderStr)
      # rfc7519Sec3_1ExampleClaimsB64 == b64UrlEncode(rfc7519Sec3_1ExampleClaimsStr)

  test "b64UrlDecode(string)":
    let jwtParts = sampleJwt.split('.')

    check:
      sampleJwtHeaderDecoded == b64UrlDecode(jwtParts[0])
      sampleJwtClaimsDecoded == b64UrlDecode(jwtParts[1])

  test "byteArrToString":
    check:
      byteArrToString(rfc7515A1ExampleHeaderBytes) == b64UrlDecode(rfc7515A1ExampleHeaderB64)
